@@ -35,11 +35,13 @@ class WorkerSet:
     def __init__(self,
                  worker,
                  worker_params,
+                 index_parent_worker,
                  worker_remote_config=default_remote_config,
                  num_workers=1,
                  local_device=None,
                  initial_weights=None,
-                 add_local_worker=True):
+                 add_local_worker=True,
+                 total_parent_workers=None):
 
         self.worker_class = worker
         self.worker_params = worker_params
@@ -51,11 +53,18 @@ class WorkerSet:
             local_params.update(
                 {"device": local_device, "initial_weights": initial_weights})
 
-            if num_workers > 0:
-                if "test_envs_factory" in local_params:
-                    _ = local_params.pop("test_envs_factory")
-                if "train_envs_factory" in local_params:
-                    _ = local_params.pop("train_envs_factory")
+            # If multiple grad workers, and multiple col workers
+            # local collection workers don't need to collect
+            if worker.__name__ == "CWorker" and total_parent_workers > 0 and num_workers > 0:
+                _ = local_params.pop("test_envs_factory")
+                _ = local_params.pop("train_envs_factory")
+
+            # If multiple grad workers the collection workers of grad worker with index 0 should not collect
+            elif worker.__name__ == "CWorker" and total_parent_workers > 0 and index_parent_worker == 0:
+
+                num_workers = 0
+                _ = local_params.pop("test_envs_factory")
+                _ = local_params.pop("train_envs_factory")
 
             self._local_worker = self._make_worker(
                 self.worker_class, index_worker=0,
